@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Small ALSA Library
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -47,6 +47,13 @@ extern "C" {
 #include "control.h"
 #include "pcm.h"
 #include "mixer.h"
+#include "rawmidi.h"
+#include "hwdep.h"
+#include "timer.h"
+#include "conf.h"
+#include "seq_event.h"
+#include "seq.h"
+#include "seqmid.h"
 
 #ifdef __cplusplus
 }
