@@ -1,4 +1,6 @@
 /*
+ * SALSA-Lib - Control Interface
+ *
  * Control privates and macros
  */
 
@@ -26,31 +28,31 @@ struct _snd_ctl {
 };
 
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_nonblock(snd_ctl_t *ctl, int nonblock)
 {
 	return _snd_set_nonblock(ctl->fd, nonblock);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_name(snd_ctl_t *ctl)
 {
 	return ctl->name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_type_t snd_ctl_type(snd_ctl_t *ctl)
 {
 	return ctl->type;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_poll_descriptors_count(snd_ctl_t *ctl)
 {
 	return 1;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_poll_descriptors(snd_ctl_t *ctl, struct pollfd *pfds,
 			     unsigned int space)
 {
@@ -58,7 +60,7 @@ int snd_ctl_poll_descriptors(snd_ctl_t *ctl, struct pollfd *pfds,
 	return 1;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_poll_descriptors_revents(snd_ctl_t *ctl, struct pollfd *pfds,
 				     unsigned int nfds, unsigned short *revents)
 {
@@ -66,7 +68,7 @@ int snd_ctl_poll_descriptors_revents(snd_ctl_t *ctl, struct pollfd *pfds,
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_subscribe_events(snd_ctl_t *ctl, int subscribe)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_SUBSCRIBE_EVENTS, &subscribe) < 0)
@@ -74,7 +76,7 @@ int snd_ctl_subscribe_events(snd_ctl_t *ctl, int subscribe)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_card_info(snd_ctl_t *ctl, snd_ctl_card_info_t *info)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_CARD_INFO, info) < 0)
@@ -82,7 +84,7 @@ int snd_ctl_card_info(snd_ctl_t *ctl, snd_ctl_card_info_t *info)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_list(snd_ctl_t *ctl, snd_ctl_elem_list_t *list)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_LIST, list) < 0)
@@ -90,7 +92,7 @@ int snd_ctl_elem_list(snd_ctl_t *ctl, snd_ctl_elem_list_t *list)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_INFO, info) < 0)
@@ -98,7 +100,7 @@ int snd_ctl_elem_info(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_add(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_ADD, info) < 0)
@@ -106,7 +108,7 @@ int snd_ctl_elem_add(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_remove(snd_ctl_t *ctl, snd_ctl_elem_id_t *id)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_REMOVE, id) < 0)
@@ -114,7 +116,7 @@ int snd_ctl_elem_remove(snd_ctl_t *ctl, snd_ctl_elem_id_t *id)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_read(snd_ctl_t *ctl, snd_ctl_elem_value_t *control)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_READ, control) < 0)
@@ -122,7 +124,7 @@ int snd_ctl_elem_read(snd_ctl_t *ctl, snd_ctl_elem_value_t *control)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_write(snd_ctl_t *ctl, snd_ctl_elem_value_t *control)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_WRITE, control) < 0)
@@ -130,7 +132,7 @@ int snd_ctl_elem_write(snd_ctl_t *ctl, snd_ctl_elem_value_t *control)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_lock(snd_ctl_t *ctl, snd_ctl_elem_id_t *id)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_LOCK, id) < 0)
@@ -138,7 +140,7 @@ int snd_ctl_elem_lock(snd_ctl_t *ctl, snd_ctl_elem_id_t *id)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_unlock(snd_ctl_t *ctl, snd_ctl_elem_id_t *id)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_UNLOCK, id) < 0)
@@ -146,7 +148,7 @@ int snd_ctl_elem_unlock(snd_ctl_t *ctl, snd_ctl_elem_id_t *id)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_hwdep_next_device(snd_ctl_t *ctl, int *device)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_HWDEP_NEXT_DEVICE, device) < 0)
@@ -154,7 +156,7 @@ int snd_ctl_hwdep_next_device(snd_ctl_t *ctl, int *device)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_hwdep_info(snd_ctl_t *ctl, snd_hwdep_info_t * info)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_HWDEP_INFO, info) < 0)
@@ -162,7 +164,7 @@ int snd_ctl_hwdep_info(snd_ctl_t *ctl, snd_hwdep_info_t * info)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_pcm_next_device(snd_ctl_t *ctl, int * device)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_PCM_NEXT_DEVICE, device) < 0)
@@ -170,7 +172,7 @@ int snd_ctl_pcm_next_device(snd_ctl_t *ctl, int * device)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_pcm_info(snd_ctl_t *ctl, snd_pcm_info_t * info)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_PCM_INFO, info) < 0)
@@ -178,7 +180,7 @@ int snd_ctl_pcm_info(snd_ctl_t *ctl, snd_pcm_info_t * info)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_pcm_prefer_subdevice(snd_ctl_t *ctl, int subdev)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_PCM_PREFER_SUBDEVICE, &subdev) < 0)
@@ -186,7 +188,7 @@ int snd_ctl_pcm_prefer_subdevice(snd_ctl_t *ctl, int subdev)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_rawmidi_next_device(snd_ctl_t *ctl, int * device)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_RAWMIDI_NEXT_DEVICE, device) < 0)
@@ -194,7 +196,7 @@ int snd_ctl_rawmidi_next_device(snd_ctl_t *ctl, int * device)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_rawmidi_info(snd_ctl_t *ctl, snd_rawmidi_info_t * info)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_RAWMIDI_INFO, info) < 0)
@@ -202,7 +204,7 @@ int snd_ctl_rawmidi_info(snd_ctl_t *ctl, snd_rawmidi_info_t * info)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_rawmidi_prefer_subdevice(snd_ctl_t *ctl, int subdev)
 {
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_RAWMIDI_PREFER_SUBDEVICE, &subdev) < 0)
@@ -210,7 +212,7 @@ int snd_ctl_rawmidi_prefer_subdevice(snd_ctl_t *ctl, int subdev)
 	return 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_read(snd_ctl_t *ctl, snd_ctl_event_t *event)
 {
 	ssize_t res = read(ctl->fd, event, sizeof(*event));
@@ -228,7 +230,7 @@ extern const char *_snd_ctl_event_type_names[];
 #define snd_ctl_elem_iface_name(iface)	_snd_ctl_elem_iface_names[iface]
 #define snd_ctl_event_type_name(type)	_snd_ctl_event_type_names[type]
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_list_alloc_space(snd_ctl_elem_list_t *obj,
 				  unsigned int entries)
 {
@@ -243,7 +245,7 @@ int snd_ctl_elem_list_alloc_space(snd_ctl_elem_list_t *obj,
 	return 0;
 }  
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_list_free_space(snd_ctl_elem_list_t *obj)
 {
 	free(obj->pids);
@@ -251,50 +253,50 @@ void snd_ctl_elem_list_free_space(snd_ctl_elem_list_t *obj)
 	obj->space = 0;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_event_elem_get_mask(const snd_ctl_event_t *obj)
 {
 	return obj->data.elem.mask;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_event_elem_get_id(const snd_ctl_event_t *obj,
 			       snd_ctl_elem_id_t *ptr)
 {
 	*ptr = obj->data.elem.id;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_event_elem_get_numid(const snd_ctl_event_t *obj)
 {
 	return obj->data.elem.id.numid;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_elem_iface_t snd_ctl_event_elem_get_interface(const snd_ctl_event_t *obj)
 {
 	return (snd_ctl_elem_iface_t)obj->data.elem.id.iface;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_event_elem_get_device(const snd_ctl_event_t *obj)
 {
 	return obj->data.elem.id.device;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_event_elem_get_subdevice(const snd_ctl_event_t *obj)
 {
 	return obj->data.elem.id.subdevice;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_event_elem_get_name(const snd_ctl_event_t *obj)
 {
 	return (const char *)obj->data.elem.id.name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_event_elem_get_index(const snd_ctl_event_t *obj)
 {
 	return obj->data.elem.id.index;
@@ -302,74 +304,74 @@ unsigned int snd_ctl_event_elem_get_index(const snd_ctl_event_t *obj)
 
 __snd_define_type(snd_ctl_elem_id);
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_id_get_numid(const snd_ctl_elem_id_t *obj)
 {
 	return obj->numid;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_elem_iface_t snd_ctl_elem_id_get_interface(const snd_ctl_elem_id_t *obj)
 {
 	return (snd_ctl_elem_iface_t)obj->iface;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_id_get_device(const snd_ctl_elem_id_t *obj)
 {
 	return obj->device;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_id_get_subdevice(const snd_ctl_elem_id_t *obj)
 {
 	return obj->subdevice;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_elem_id_get_name(const snd_ctl_elem_id_t *obj)
 {
 	return (const char *)obj->name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_id_get_index(const snd_ctl_elem_id_t *obj)
 {
 	return obj->index;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_id_set_numid(snd_ctl_elem_id_t *obj, unsigned int val)
 {
 	obj->numid = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_id_set_interface(snd_ctl_elem_id_t *obj,
 				   snd_ctl_elem_iface_t val)
 {
 	obj->iface = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_id_set_device(snd_ctl_elem_id_t *obj, unsigned int val)
 {
 	obj->device = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_id_set_subdevice(snd_ctl_elem_id_t *obj, unsigned int val)
 {
 	obj->subdevice = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_id_set_name(snd_ctl_elem_id_t *obj, const char *val)
 {
 	strncpy((char *)obj->name, val, sizeof(obj->name));
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_id_set_index(snd_ctl_elem_id_t *obj, unsigned int val)
 {
 	obj->index = val;
@@ -377,43 +379,43 @@ void snd_ctl_elem_id_set_index(snd_ctl_elem_id_t *obj, unsigned int val)
 
 __snd_define_type(snd_ctl_card_info);
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_card_info_get_card(const snd_ctl_card_info_t *obj)
 {
 	return obj->card;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_card_info_get_id(const snd_ctl_card_info_t *obj)
 {
 	return (const char *)obj->id;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_card_info_get_driver(const snd_ctl_card_info_t *obj)
 {
 	return (const char *)obj->driver;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_card_info_get_name(const snd_ctl_card_info_t *obj)
 {
 	return (const char *)obj->name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_card_info_get_longname(const snd_ctl_card_info_t *obj)
 {
 	return (const char *)obj->longname;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_card_info_get_mixername(const snd_ctl_card_info_t *obj)
 {
 	return (const char *)obj->mixername;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_card_info_get_components(const snd_ctl_card_info_t *obj)
 {
 	return (const char *)obj->components;
@@ -421,7 +423,7 @@ const char *snd_ctl_card_info_get_components(const snd_ctl_card_info_t *obj)
 
 __snd_define_type(snd_ctl_event);
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_event_type_t snd_ctl_event_get_type(const snd_ctl_event_t *obj)
 {
 	return (snd_ctl_event_type_t) obj->type;
@@ -429,67 +431,67 @@ snd_ctl_event_type_t snd_ctl_event_get_type(const snd_ctl_event_t *obj)
 
 __snd_define_type(snd_ctl_elem_list);
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_list_set_offset(snd_ctl_elem_list_t *obj, unsigned int val)
 {
 	obj->offset = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_list_get_used(const snd_ctl_elem_list_t *obj)
 {
 	return obj->used;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_list_get_count(const snd_ctl_elem_list_t *obj)
 {
 	return obj->count;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_list_get_id(const snd_ctl_elem_list_t *obj,
 			      unsigned int idx, snd_ctl_elem_id_t *ptr)
 {
 	*ptr = obj->pids[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_list_get_numid(const snd_ctl_elem_list_t *obj,
 					 unsigned int idx)
 {
 	return obj->pids[idx].numid;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_elem_iface_t snd_ctl_elem_list_get_interface(const snd_ctl_elem_list_t *obj,
 						     unsigned int idx)
 {
 	return (snd_ctl_elem_iface_t) obj->pids[idx].iface;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_list_get_device(const snd_ctl_elem_list_t *obj,
 					  unsigned int idx)
 {
 	return obj->pids[idx].device;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_list_get_subdevice(const snd_ctl_elem_list_t *obj,
 					     unsigned int idx)
 {
 	return obj->pids[idx].subdevice;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_elem_list_get_name(const snd_ctl_elem_list_t *obj,
 				       unsigned int idx)
 {
 	return (const char *)obj->pids[idx].name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_list_get_index(const snd_ctl_elem_list_t *obj,
 					 unsigned int idx)
 {
@@ -498,55 +500,55 @@ unsigned int snd_ctl_elem_list_get_index(const snd_ctl_elem_list_t *obj,
 
 __snd_define_type(snd_ctl_elem_info);
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_elem_type_t snd_ctl_elem_info_get_type(const snd_ctl_elem_info_t *obj)
 {
 	return (snd_ctl_elem_type_t) obj->type;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_readable(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_READ);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_writable(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_WRITE);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_volatile(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_VOLATILE);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_inactive(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_INACTIVE);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_locked(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_LOCK);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_owner(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_OWNER);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_user(const snd_ctl_elem_info_t *obj)
 {
 	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_USER);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_tlv_readable(const snd_ctl_elem_info_t *obj)
 {
 #if SALSA_HAS_TLV_SUPPORT
@@ -556,7 +558,7 @@ int snd_ctl_elem_info_is_tlv_readable(const snd_ctl_elem_info_t *obj)
 #endif
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_tlv_writable(const snd_ctl_elem_info_t *obj)
 {
 #if SALSA_HAS_TLV_SUPPORT
@@ -566,7 +568,7 @@ int snd_ctl_elem_info_is_tlv_writable(const snd_ctl_elem_info_t *obj)
 #endif
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_tlv_commandable(const snd_ctl_elem_info_t *obj)
 {
 #if SALSA_HAS_TLV_SUPPORT
@@ -576,73 +578,73 @@ int snd_ctl_elem_info_is_tlv_commandable(const snd_ctl_elem_info_t *obj)
 #endif
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 pid_t snd_ctl_elem_info_get_owner(const snd_ctl_elem_info_t *obj)
 {
 	return obj->owner;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_info_get_count(const snd_ctl_elem_info_t *obj)
 {
 	return obj->count;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long snd_ctl_elem_info_get_min(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.integer.min;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long snd_ctl_elem_info_get_max(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.integer.max;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long snd_ctl_elem_info_get_step(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.integer.step;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long long snd_ctl_elem_info_get_min64(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.integer64.min;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long long snd_ctl_elem_info_get_max64(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.integer64.max;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long long snd_ctl_elem_info_get_step64(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.integer64.step;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_info_get_items(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.enumerated.items;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_item(snd_ctl_elem_info_t *obj, unsigned int val)
 {
 	obj->value.enumerated.item = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_elem_info_get_item_name(const snd_ctl_elem_info_t *obj)
 {
 	return obj->value.enumerated.name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_get_dimensions(const snd_ctl_elem_info_t *obj)
 {
 	int i;
@@ -652,7 +654,7 @@ int snd_ctl_elem_info_get_dimensions(const snd_ctl_elem_info_t *obj)
 	return i + 1;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_get_dimension(const snd_ctl_elem_info_t *obj,
 				    unsigned int idx)
 {
@@ -661,274 +663,274 @@ int snd_ctl_elem_info_get_dimension(const snd_ctl_elem_info_t *obj,
 	return obj->dimen.d[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_get_id(const snd_ctl_elem_info_t *obj,
 			      snd_ctl_elem_id_t *ptr)
 {
 	*ptr = obj->id;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_info_get_numid(const snd_ctl_elem_info_t *obj)
 {
 	return obj->id.numid;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_elem_iface_t snd_ctl_elem_info_get_interface(const snd_ctl_elem_info_t *obj)
 {
 	return (snd_ctl_elem_iface_t) obj->id.iface;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_info_get_device(const snd_ctl_elem_info_t *obj)
 {
 	return obj->id.device;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_info_get_subdevice(const snd_ctl_elem_info_t *obj)
 {
 	return obj->id.subdevice;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_elem_info_get_name(const snd_ctl_elem_info_t *obj)
 {
 	return (const char *)obj->id.name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_info_get_index(const snd_ctl_elem_info_t *obj)
 {
 	return obj->id.index;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_id(snd_ctl_elem_info_t *obj,
 			      const snd_ctl_elem_id_t *ptr)
 {
 	obj->id = *ptr;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_numid(snd_ctl_elem_info_t *obj, unsigned int val)
 {
 	obj->id.numid = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_interface(snd_ctl_elem_info_t *obj,
 				     snd_ctl_elem_iface_t val)
 {
 	obj->id.iface = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_device(snd_ctl_elem_info_t *obj, unsigned int val)
 {
 	obj->id.device = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_subdevice(snd_ctl_elem_info_t *obj,
 				     unsigned int val)
 {
 	obj->id.subdevice = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_name(snd_ctl_elem_info_t *obj, const char *val)
 {
 	strncpy((char *)obj->id.name, val, sizeof(obj->id.name));
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_info_set_index(snd_ctl_elem_info_t *obj, unsigned int val)
 {
 	obj->id.index = val;
 }
 
 __snd_define_type(snd_ctl_elem_value);
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_get_id(const snd_ctl_elem_value_t *obj,
 			       snd_ctl_elem_id_t *ptr)
 {
 	*ptr = obj->id;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_value_get_numid(const snd_ctl_elem_value_t *obj)
 {
 	return obj->id.numid;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_elem_iface_t snd_ctl_elem_value_get_interface(const snd_ctl_elem_value_t *obj)
 {
 	return (snd_ctl_elem_iface_t) obj->id.iface;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_value_get_device(const snd_ctl_elem_value_t *obj)
 {
 	return obj->id.device;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_value_get_subdevice(const snd_ctl_elem_value_t *obj)
 {
 	return obj->id.subdevice;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_ctl_elem_value_get_name(const snd_ctl_elem_value_t *obj)
 {
 	return (const char *)obj->id.name;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_value_get_index(const snd_ctl_elem_value_t *obj)
 {
 	return obj->id.index;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_id(snd_ctl_elem_value_t *obj,
 			       const snd_ctl_elem_id_t *ptr)
 {
 	obj->id = *ptr;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_numid(snd_ctl_elem_value_t *obj, unsigned int val)
 {
 	obj->id.numid = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_interface(snd_ctl_elem_value_t *obj,
 				      snd_ctl_elem_iface_t val)
 {
 	obj->id.iface = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_device(snd_ctl_elem_value_t *obj, unsigned int val)
 {
 	obj->id.device = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_subdevice(snd_ctl_elem_value_t *obj,
 				      unsigned int val)
 {
 	obj->id.subdevice = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_name(snd_ctl_elem_value_t *obj, const char *val)
 {
 	strncpy((char *)obj->id.name, val, sizeof(obj->id.name));
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_index(snd_ctl_elem_value_t *obj, unsigned int val)
 {
 	obj->id.index = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_ctl_elem_value_get_boolean(const snd_ctl_elem_value_t *obj,
 				   unsigned int idx)
 {
 	return obj->value.integer.value[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long snd_ctl_elem_value_get_integer(const snd_ctl_elem_value_t *obj,
 				    unsigned int idx)
 {
 	return obj->value.integer.value[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 long long snd_ctl_elem_value_get_integer64(const snd_ctl_elem_value_t *obj,
 					   unsigned int idx)
 {
 	return obj->value.integer64.value[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned int snd_ctl_elem_value_get_enumerated(const snd_ctl_elem_value_t *obj,
 					       unsigned int idx)
 {
 	return obj->value.enumerated.item[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 unsigned char snd_ctl_elem_value_get_byte(const snd_ctl_elem_value_t *obj,
 					  unsigned int idx)
 {
 	return obj->value.bytes.data[idx];
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_boolean(snd_ctl_elem_value_t *obj,
 				    unsigned int idx, long val)
 {
 	obj->value.integer.value[idx] = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_integer(snd_ctl_elem_value_t *obj,
 				    unsigned int idx, long val)
 {
 	obj->value.integer.value[idx] = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_integer64(snd_ctl_elem_value_t *obj,
 				      unsigned int idx, long long val)
 {
 	obj->value.integer64.value[idx] = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_enumerated(snd_ctl_elem_value_t *obj,
 				       unsigned int idx, unsigned int val)
 {
 	obj->value.enumerated.item[idx] = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_byte(snd_ctl_elem_value_t *obj, unsigned int idx,
 				 unsigned char val)
 {
 	obj->value.bytes.data[idx] = val;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_set_bytes(snd_ctl_elem_value_t *obj, void *data, size_t size)
 {
 	if (size < sizeof(obj->value.bytes.data))
 		memcpy(obj->value.bytes.data, data, size);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 const void * snd_ctl_elem_value_get_bytes(const snd_ctl_elem_value_t *obj)
 {
 	return obj->value.bytes.data;
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_get_iec958(const snd_ctl_elem_value_t *obj,
 				   snd_aes_iec958_t *ptr)
 {
 	memcpy(ptr, &obj->value.iec958, sizeof(*ptr));
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 void snd_ctl_elem_value_set_iec958(snd_ctl_elem_value_t *obj,
 				   const snd_aes_iec958_t *ptr)
 {
@@ -938,70 +940,70 @@ void snd_ctl_elem_value_set_iec958(snd_ctl_elem_value_t *obj,
 /*
  */
 #if !SALSA_HAS_TLV_SUPPORT
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_elem_tlv_read(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 			  unsigned int *tlv, unsigned int tlv_size)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_elem_tlv_write(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 			   const unsigned int *tlv)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_elem_tlv_command(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 			     const unsigned int *tlv)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_tlv_parse_dB_info(unsigned int *tlv, unsigned int tlv_size,
 			  unsigned int **db_tlvp)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_tlv_get_dB_range(unsigned int *tlv, long rangemin, long rangemax,
 			 long *min, long *max)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_tlv_convert_to_dB(unsigned int *tlv, long rangemin, long rangemax,
 			  long volume, long *db_gain)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_tlv_convert_from_dB(unsigned int *tlv, long rangemin, long rangemax,
 			    long db_gain, long *value, int xdir)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_get_dB_range(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 			 long *min, long *max)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_convert_to_dB(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 			  long volume, long *db_gain)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_convert_from_dB(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 			    long db_gain, long *value, int xdir)
 {
@@ -1013,37 +1015,37 @@ int snd_ctl_convert_from_dB(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
  * not implemented yet
  */
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_open_lconf(snd_ctl_t **ctlp, const char *name,
 		       int mode, snd_config_t *lconf)
 {
 	return -ENXIO;
 }
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_set_power_state(snd_ctl_t *ctl, unsigned int state)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_ctl_get_power_state(snd_ctl_t *ctl, unsigned int *state)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_device_name_hint(int card, const char *iface, void ***hints)
 {
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_device_name_free_hint(void **hints)
 {
 	return 0;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 char *snd_device_name_get_hint(const void *hint, const char *id)
 {
 	return NULL;
@@ -1051,7 +1053,7 @@ char *snd_device_name_get_hint(const void *hint, const char *id)
 
 #if SALSA_HAS_ASYNC_SUPPORT
 
-static inline
+__SALSA_EXPORT_FUNC
 snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler)
 {
 	return (snd_ctl_t *) handler->rec;
@@ -1059,7 +1061,7 @@ snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler)
 
 #else
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 int snd_async_add_ctl_handler(snd_async_handler_t **handler, snd_ctl_t *ctl, 
 			      snd_async_callback_t callback,
 			      void *private_data)
@@ -1067,7 +1069,7 @@ int snd_async_add_ctl_handler(snd_async_handler_t **handler, snd_ctl_t *ctl,
 	return -ENXIO;
 }
 
-static inline __SALSA_NOT_IMPLEMENTED
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
 snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler)
 {
 	return NULL;
@@ -1075,4 +1077,15 @@ snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler)
 
 #endif /* SALSA_HAS_ASYNC_SUPPORT */
 
+#if SALSA_HAS_TLV_SUPPORT
+__SALSA_EXPORT_FUNC
+int snd_tlv_parse_dB_info(unsigned int *tlv, unsigned int tlv_size,
+			  unsigned int **db_tlvp)
+{
+	/* just for simplicity */
+	*db_tlvp = tlv;
+	return 0;
+}
+#endif /* SALSA_HAS_TLV_SUPPORT */
+
 #endif /* __ALSA_CTL_MACROS_H */
