@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Hardware Dependent Interface
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -23,11 +23,7 @@
 #define __ALSA_HWDEP_H
 
 #include "recipe.h"
-#include "global.h"
-#include "hwdep_types.h"
-
-int snd_hwdep_open(snd_hwdep_t **hwdep, const char *name, int mode);
-int snd_hwdep_close(snd_hwdep_t *hwdep);
+#include "hwdep_func.h"
 
 #include "hwdep_macros.h"
 
