@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - PCM Interface
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -60,7 +60,7 @@ static int open_with_subdev(const char *filename, int fmode,
 		fd = open(filename, fmode);
 		if (fd < 0)
 		        return -errno;
-		memset(&info, 0, sizeof(info));
+		memzero_valgrind(&info, sizeof(info));
 		if (ioctl(fd, SNDRV_PCM_IOCTL_INFO, &info) >= 0 &&
 		    info.subdevice == subdev) {
 			snd_ctl_close(ctl);
@@ -113,7 +113,7 @@ int snd_pcm_open(snd_pcm_t **pcmp, const char *name,
 	}
 	if (subdev < 0) {
 		snd_pcm_info_t info;
-		memset(&info, 0, sizeof(info));
+		memzero_valgrind(&info, sizeof(info));
 		if (ioctl(fd, SNDRV_PCM_IOCTL_INFO, &info) < 0) {
 			err = -errno;
 			goto error;
@@ -200,6 +200,9 @@ snd_pcm_sframes_t snd_pcm_writei(snd_pcm_t *pcm, const void *buffer,
 {
 	struct sndrv_xferi xferi;
 
+#ifdef DELIGHT_VALGRIND
+	xferi.result = 0;
+#endif
 	xferi.buf = (char*) buffer;
 	xferi.frames = size;
 	if (ioctl(pcm->fd, SNDRV_PCM_IOCTL_WRITEI_FRAMES, &xferi) < 0)
@@ -213,6 +216,9 @@ snd_pcm_sframes_t snd_pcm_writen(snd_pcm_t *pcm, void **bufs,
 {
 	struct sndrv_xfern xfern;
 
+#ifdef DELIGHT_VALGRIND
+	xfern.result = 0;
+#endif
 	xfern.bufs = bufs;
 	xfern.frames = size;
 	if (ioctl(pcm->fd, SNDRV_PCM_IOCTL_WRITEN_FRAMES, &xfern) < 0)
@@ -226,6 +232,9 @@ snd_pcm_sframes_t snd_pcm_readi(snd_pcm_t *pcm, void *buffer,
 {
 	struct sndrv_xferi xferi;
 
+#ifdef DELIGHT_VALGRIND
+	xferi.result = 0;
+#endif
 	xferi.buf = buffer;
 	xferi.frames = size;
 	if (ioctl(pcm->fd, SNDRV_PCM_IOCTL_READI_FRAMES, &xferi) < 0)
@@ -239,6 +248,9 @@ snd_pcm_sframes_t snd_pcm_readn(snd_pcm_t *pcm, void **bufs,
 {
 	struct sndrv_xfern xfern;
 
+#ifdef DELIGHT_VALGRIND
+	xfern.result = 0;
+#endif
 	xfern.bufs = bufs;
 	xfern.frames = size;
 	if (ioctl(pcm->fd, SNDRV_PCM_IOCTL_READN_FRAMES, &xfern) < 0)
@@ -936,6 +948,9 @@ static snd_pcm_uframes_t snd_pcm_mmap_avail(snd_pcm_t *pcm)
 		return snd_pcm_mmap_capture_avail(pcm);
 }
 
+snd_pcm_sframes_t snd_pcm_hw_forwardable(snd_pcm_t *pcm)
+	__attribute__ ((alias("snd_pcm_mmap_avail")));
+
 snd_pcm_sframes_t snd_pcm_avail_update(snd_pcm_t *pcm)
 {
 	snd_pcm_uframes_t avail;
