@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - PCM HW/SW PARAMS
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -413,13 +413,6 @@ static int snd_pcm_sw_params_default(snd_pcm_t *pcm,
 	return 0;
 }
 
-static int snd_pcm_hw_refine(snd_pcm_t *pcm, snd_pcm_hw_params_t *params)
-{
-	if (ioctl(pcm->fd, SNDRV_PCM_IOCTL_HW_REFINE, params) < 0)
-		return -errno;
-	return 0;
-}
-
 static inline int hw_is_mask(int var)
 {
 	return var >= SNDRV_PCM_HW_PARAM_FIRST_MASK &&
@@ -928,6 +921,11 @@ int _snd_pcm_hw_param_set_near(snd_pcm_t *pcm, snd_pcm_hw_params_t *params,
 	return err;
 }
 
+snd_mask_t *_snd_pcm_hw_param_get_mask(snd_pcm_hw_params_t *params, int var)
+{
+	return hw_param_mask(params, var);
+}
+
 static int snd_pcm_hw_params_choose(snd_pcm_t *pcm, snd_pcm_hw_params_t *params)
 {
 	struct param_choice {
@@ -974,7 +972,10 @@ static int _snd_pcm_hw_params(snd_pcm_t *pcm, snd_pcm_hw_params_t *params)
 	snd_pcm_hw_free(pcm);
 	if (ioctl(pcm->fd, SNDRV_PCM_IOCTL_HW_PARAMS, params) < 0)
 		return -errno;
-
+#if 0
+	params->info &= ~0xf0000000;
+	params->info |= (pcm->monotonic ? SND_PCM_INFO_MONOTONIC : 0);
+#endif
 	pcm->setup = 1;
 	pcm->hw_params = *params;
 	
