@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Raw MIDI Interface
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -50,7 +50,7 @@ static int open_with_subdev(const char *filename, int fmode,
 		fd = open(filename, fmode);
 		if (fd < 0)
 		        return -errno;
-		memset(&info, 0, sizeof(info));
+		memzero_valgrind(&info, sizeof(info));
 		info.stream = ((fmode & O_ACCMODE) != O_RDONLY) ?
 			SNDRV_RAWMIDI_STREAM_OUTPUT : SNDRV_RAWMIDI_STREAM_INPUT;
 		if (ioctl(fd, SNDRV_RAWMIDI_IOCTL_INFO, &info) >= 0 &&
@@ -82,7 +82,7 @@ static snd_rawmidi_t *new_rmidi(snd_rawmidi_hw_t *hw, int stream, int mode)
 
 	rmidi->params.buffer_size = 4096;
 	rmidi->params.avail_min = 1;
-	rmidi->no_active_sending = 1;
+	rmidi->params.no_active_sensing = 1;
 	snd_rawmidi_params(rmidi, &rmidi->params);
 
 	return rmidi;
