@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Timer Interface
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -65,7 +65,7 @@ int snd_timer_open(snd_timer_t **handle, const char *name, int mode)
 			return err;
 		}
 	}
-	memset(&sel, 0, sizeof(sel));
+	memzero_valgrind(&sel, sizeof(sel));
 	sel.id.dev_class = dev_class;
 	sel.id.dev_sclass = dev_sclass;
 	sel.id.card = card;
