@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Timer Interface
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -23,12 +23,7 @@
 #define __ALSA_TIMER_H
 
 #include "recipe.h"
-#include "global.h"
-#include "timer_types.h"
-
-
-int snd_timer_open(snd_timer_t **handle, const char *name, int mode);
-int snd_timer_close(snd_timer_t *handle);
+#include "timer_func.h"
 
 #include "timer_macros.h"
 
